@@ -1,6 +1,6 @@
 /*
    This file is part of the BOLT-LMM linear mixed model software package
-   developed by Po-Ru Loh.  Copyright (C) 2014-2021 Harvard University.
+   developed by Po-Ru Loh.  Copyright (C) 2014-2022 Harvard University.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -54,13 +54,13 @@ int main(int argc, char *argv[]) {
 
   cout << "                      +-----------------------------+" << endl;
   cout << "                      |                       ___   |" << endl;
-  cout << "                      |   BOLT-LMM, v2.3.6   /_ /   |" << endl;
-  cout << "                      |   October 29, 2021    /_/   |" << endl;
+  cout << "                      |   BOLT-LMM, v2.4     /_ /   |" << endl;
+  cout << "                      |   July 22, 2022       /_/   |" << endl;
   cout << "                      |   Po-Ru Loh            //   |" << endl;
   cout << "                      |                        /    |" << endl;
   cout << "                      +-----------------------------+" << endl;
   cout << endl;
-  cout << "Copyright (C) 2014-2021 Harvard University." << endl;
+  cout << "Copyright (C) 2014-2022 Harvard University." << endl;
   cout << "Distributed under the GNU GPLv3 open source license." << endl << endl;
 
 #ifdef VERBOSE
@@ -472,6 +472,7 @@ int main(int argc, char *argv[]) {
 	    numFound++;
 	  }
 	}
+	fin.close();
 	if (numFound < 1000) {
 	  cerr << "ERROR: Found LD Scores for only " << numFound << "/" << LDscores.size()
 	       << " SNPs" << endl;
@@ -513,6 +514,7 @@ int main(int argc, char *argv[]) {
 	    numFound++;
 	  }
 	}
+	fin.close();
       }
       cout << "Found LD Scores for " << numFound << "/" << LDscores.size() << " SNPs" << endl;
 
@@ -624,7 +626,8 @@ int main(int argc, char *argv[]) {
     }
 
     if (!params.predBetasFile.empty()) {
-      cout << endl << "=== Computing and writing betas for risk prediction ===" << endl << endl;
+      cout << endl << "=== Computing and writing betas for polygenic prediction ===" << endl
+	   << endl;
 
       if (pEst == BoltParams::MIX_PARAM_ESTIMATE_FLAG ||
 	  f2Est == BoltParams::MIX_PARAM_ESTIMATE_FLAG)
